@@ -1,16 +1,7 @@
 #ifndef PYTHONIC_OPERATOR_IFLOORDIV__HPP
 #define PYTHONIC_OPERATOR_IFLOORDIV__HPP
 
+#include "pythonic/include/operator_/__ifloordiv__.hpp"
 #include "pythonic/operator_/ifloordiv.hpp"
 
-namespace pythonic {
-
-    namespace operator_ {
-
-        FPROXY(pythonic::operator_, __ifloordiv__, ifloordiv);
-    }
-
-}
-
 #endif
-
